// This file is part of GHome Mover (http://www.brookepeig.com/ghomemover)
// GHome Mover was created by Daniel Brooke Peig (daniel@brookepeig.com, http://www.brookepeig.com)
//
//
//
//    GHome Mover is free software; you can redistribute it and/or modify
//    it under the terms of the GNU General Public License as published by
//    the Free Software Foundation; either version 2 of the License, or
//    (at your option) any later version.
//
//    GHome Mover is distributed in the hope that it will be useful,
//    but WITHOUT ANY WARRANTY; without even the implied warranty of
//    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//    GNU General Public License for more details.
//
//    You should have received a copy of the GNU General Public License
//    along with GHome Mover; if not, write to the Free Software
//    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA


#ifdef HAVE_CONFIG_H
#  include <config.h>
#endif

#include <gnome.h>


#include "callbacks.h"
#include "interface.h"
#include "support.h"
#include "custom_func.h"
#include "string.h"

// These two functions above returns the location of some pixmaps used
// in GHome Mover (they are used in the interface.c source). I made this
// to avoid troubles when building new Glade modifications.

char *ghomemover_logo_pixmap ()
{
	static char pixmapsdir[512];
	strcpy (pixmapsdir, PACKAGE_PIXMAPS_DIR);
	strcat (pixmapsdir, "/main_logo.png");
	return pixmapsdir;
}

char *dbp_logo_pixmap()
{
	static char pixmapsdir[512];
	strcpy (pixmapsdir, PACKAGE_PIXMAPS_DIR);
	strcat (pixmapsdir, "/logo.png");
	return pixmapsdir;
}

// End of pixmap functions

// Procedures before closing the application
void exit_program_routines()
{
 gtk_main_quit ();
}


// Main function, maybe ill put it on other file.
int on_ghm_begin_btn_clicked(GtkButton *button, gpointer user_data)
{
// Poiters for the widgets used on this function

// Source data
GtkWidget *ghm_source_user = lookup_widget(GTK_WIDGET(button), "ghm_source_user");
GtkWidget *ghm_source_dir = lookup_widget(GTK_WIDGET(button), "ghm_source_dir");
GtkWidget *ghm_source_group = lookup_widget(GTK_WIDGET(button), "ghm_source_group");

// Destination data	
GtkWidget *ghm_dest_user = lookup_widget(GTK_WIDGET(button), "ghm_dest_user");
GtkWidget *ghm_dest_dir = lookup_widget(GTK_WIDGET(button), "ghm_dest_dir");
GtkWidget *ghm_dest_group = lookup_widget(GTK_WIDGET(button), "ghm_dest_group");

// Options data
GtkWidget *ghm_chown_check = lookup_widget(GTK_WIDGET(button), "ghm_chown_check");
GtkWidget *ghm_string_check = lookup_widget(GTK_WIDGET(button), "ghm_string_check");
GtkWidget *ghm_smart_check = lookup_widget(GTK_WIDGET(button), "ghm_smart_check");	

// Status Bar
GtkWidget *statusbar1 = lookup_widget(GTK_WIDGET(button), "statusbar1");	
	
// Log View
GtkWidget *ghm_log_view = lookup_widget(GTK_WIDGET(button), "ghm_log_view");

// Notice that my initialization values are very confortable
// I dont know why didnt used a define.
char current_dir[512];
char new_file_loc[512];

char source_dir[512];
char dest_dir[512];
char source_user[512];
char dest_user[512];
char source_group[512];
char dest_group[512];
char log_message[512];

int chown_check;
int string_check;
int smart_check;

int smart_check_result = 0;

char commando[1024];

FILE *current_file;
char fileline[256];

int context_id = gtk_statusbar_get_context_id(GTK_STATUSBAR (statusbar1), _("G Home Mover Status Bar"));


// Set a status bar message
gtk_statusbar_push(GTK_STATUSBAR (statusbar1), context_id, _("Processing... This may take a few minutes"));


// Clear the log buffer
gtk_text_buffer_set_text(gtk_text_view_get_buffer (GTK_TEXT_VIEW (ghm_log_view)),"",0);


// Get the data from the fields into the arrays (safer)
strcpy(source_dir, gtk_entry_get_text (GTK_ENTRY (ghm_source_dir)));
strcpy(dest_dir, gtk_entry_get_text (GTK_ENTRY (ghm_dest_dir)));
strcpy(source_user, gtk_entry_get_text (GTK_ENTRY (ghm_source_user)));
strcpy(dest_user, gtk_entry_get_text (GTK_ENTRY (ghm_dest_user)));
strcpy(source_group, gtk_entry_get_text (GTK_ENTRY (ghm_source_group)));
strcpy(dest_group, gtk_entry_get_text (GTK_ENTRY (ghm_dest_group)));

chown_check = gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (ghm_chown_check));
string_check = gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (ghm_string_check));
smart_check = gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (ghm_smart_check));

// Verify if all the fields have been completed
strcpy(log_message, _("Checking if all the fields are completed..."));
gtk_text_buffer_insert_at_cursor(gtk_text_view_get_buffer (GTK_TEXT_VIEW (ghm_log_view)),log_message,strlen(log_message));
gtk_text_view_scroll_mark_onscreen (GTK_TEXT_VIEW (ghm_log_view), gtk_text_buffer_get_insert(gtk_text_view_get_buffer (GTK_TEXT_VIEW (ghm_log_view))));

if (strlen(source_dir) == 0 || strlen(dest_dir) == 0 || strlen(source_user) == 0 || strlen(dest_user) == 0 || strlen(source_group) == 0 || strlen(dest_group) == 0)
{
 	strcpy(log_message, _("FAILED\nProcess stopped."));
 	gtk_text_buffer_insert_at_cursor(gtk_text_view_get_buffer (GTK_TEXT_VIEW (ghm_log_view)),log_message,strlen(log_message));
 	gtk_text_view_scroll_mark_onscreen (GTK_TEXT_VIEW (ghm_log_view), gtk_text_buffer_get_insert(gtk_text_view_get_buffer (GTK_TEXT_VIEW (ghm_log_view))));
	gtk_statusbar_push(GTK_STATUSBAR (statusbar1), context_id, _("Process failed! See log for more information."));
	return 1;
}

else
{
	strcpy(log_message, _("OK\n"));
	gtk_text_buffer_insert_at_cursor(gtk_text_view_get_buffer (GTK_TEXT_VIEW (ghm_log_view)),log_message,strlen(log_message));
	gtk_text_view_scroll_mark_onscreen (GTK_TEXT_VIEW (ghm_log_view), gtk_text_buffer_get_insert(gtk_text_view_get_buffer (GTK_TEXT_VIEW (ghm_log_view))));
}

// Verify if the dirs exists
strcpy(log_message, _("Checking if the source dir exists..."));
gtk_text_buffer_insert_at_cursor(gtk_text_view_get_buffer (GTK_TEXT_VIEW (ghm_log_view)),log_message,strlen(log_message));
gtk_text_view_scroll_mark_onscreen (GTK_TEXT_VIEW (ghm_log_view), gtk_text_buffer_get_insert(gtk_text_view_get_buffer (GTK_TEXT_VIEW (ghm_log_view))));

strcpy(commando, "cd ");
strcat(commando, source_dir);

if (system(commando) != 0)
{
 	strcpy(log_message, _("FAILED\nProcess stopped."));
 	gtk_text_buffer_insert_at_cursor(gtk_text_view_get_buffer (GTK_TEXT_VIEW (ghm_log_view)),log_message,strlen(log_message));
 	gtk_text_view_scroll_mark_onscreen (GTK_TEXT_VIEW (ghm_log_view), gtk_text_buffer_get_insert(gtk_text_view_get_buffer (GTK_TEXT_VIEW (ghm_log_view))));
	gtk_statusbar_push(GTK_STATUSBAR (statusbar1), context_id, _("Process failed! See log for more information."));
	return 1;
}

else
{
	strcpy(log_message, _("OK\n"));
	gtk_text_buffer_insert_at_cursor(gtk_text_view_get_buffer (GTK_TEXT_VIEW (ghm_log_view)),log_message,strlen(log_message));
	gtk_text_view_scroll_mark_onscreen (GTK_TEXT_VIEW (ghm_log_view), gtk_text_buffer_get_insert(gtk_text_view_get_buffer (GTK_TEXT_VIEW (ghm_log_view))));
}

strcpy(log_message, _("Checking if the destination dir exists..."));
gtk_text_buffer_insert_at_cursor(gtk_text_view_get_buffer (GTK_TEXT_VIEW (ghm_log_view)),log_message,strlen(log_message));
gtk_text_view_scroll_mark_onscreen (GTK_TEXT_VIEW (ghm_log_view), gtk_text_buffer_get_insert(gtk_text_view_get_buffer (GTK_TEXT_VIEW (ghm_log_view))));

strcpy(commando, "cd ");
strcat(commando, dest_dir);

if (system(commando) != 0)
{
	strcpy(log_message, _("NO\nCreating the destination dir..."));
	gtk_text_buffer_insert_at_cursor(gtk_text_view_get_buffer (GTK_TEXT_VIEW (ghm_log_view)),log_message,strlen(log_message));
	gtk_text_view_scroll_mark_onscreen (GTK_TEXT_VIEW (ghm_log_view), gtk_text_buffer_get_insert(gtk_text_view_get_buffer (GTK_TEXT_VIEW (ghm_log_view))));
	
	strcpy(commando, "mkdir ");
	strcat(commando, dest_dir);
	
	if (system(commando) != 0)
	{
		strcpy(log_message, _("FAILED\nProcess stopped."));
		gtk_text_buffer_insert_at_cursor(gtk_text_view_get_buffer (GTK_TEXT_VIEW (ghm_log_view)),log_message,strlen(log_message));
		gtk_text_view_scroll_mark_onscreen (GTK_TEXT_VIEW (ghm_log_view), gtk_text_buffer_get_insert(gtk_text_view_get_buffer (GTK_TEXT_VIEW (ghm_log_view))));
		gtk_statusbar_push(GTK_STATUSBAR (statusbar1), context_id, _("Process failed! See log for more information."));
		return 1;
	}
	else
	{
		strcpy(log_message, _("OK\n"));
		gtk_text_buffer_insert_at_cursor(gtk_text_view_get_buffer (GTK_TEXT_VIEW (ghm_log_view)),log_message,strlen(log_message));
		gtk_text_view_scroll_mark_onscreen (GTK_TEXT_VIEW (ghm_log_view), gtk_text_buffer_get_insert(gtk_text_view_get_buffer (GTK_TEXT_VIEW (ghm_log_view))));
	}
}
else
{
	strcpy(log_message, _("OK\n"));
	gtk_text_buffer_insert_at_cursor(gtk_text_view_get_buffer (GTK_TEXT_VIEW (ghm_log_view)),log_message,strlen(log_message));
	gtk_text_view_scroll_mark_onscreen (GTK_TEXT_VIEW (ghm_log_view), gtk_text_buffer_get_insert(gtk_text_view_get_buffer (GTK_TEXT_VIEW (ghm_log_view))));
}

// Copies the files from a directory to another
strcpy(log_message, _("Coping the files..."));
gtk_text_buffer_insert_at_cursor(gtk_text_view_get_buffer (GTK_TEXT_VIEW (ghm_log_view)),log_message,strlen(log_message));
gtk_text_view_scroll_mark_onscreen (GTK_TEXT_VIEW (ghm_log_view), gtk_text_buffer_get_insert(gtk_text_view_get_buffer (GTK_TEXT_VIEW (ghm_log_view))));	

if (copy_files(source_dir, dest_dir) == 0)
{
	strcpy(log_message, _("OK\n"));
	gtk_text_buffer_insert_at_cursor(gtk_text_view_get_buffer (GTK_TEXT_VIEW (ghm_log_view)),log_message,strlen(log_message));
	gtk_text_view_scroll_mark_onscreen (GTK_TEXT_VIEW (ghm_log_view), gtk_text_buffer_get_insert(gtk_text_view_get_buffer (GTK_TEXT_VIEW (ghm_log_view))));
}

else
{
	strcpy(log_message, _("FAILED\nProcess stopped."));
	gtk_text_buffer_insert_at_cursor(gtk_text_view_get_buffer (GTK_TEXT_VIEW (ghm_log_view)),log_message,strlen(log_message));
	gtk_text_view_scroll_mark_onscreen (GTK_TEXT_VIEW (ghm_log_view), gtk_text_buffer_get_insert(gtk_text_view_get_buffer (GTK_TEXT_VIEW (ghm_log_view))));
	gtk_statusbar_push(GTK_STATUSBAR (statusbar1), context_id, _("Process failed! See log for more information."));
	return 1;
}

// Creates a list of the contents in the dir
strcpy(log_message, _("Indexing the files..."));
gtk_text_buffer_insert_at_cursor(gtk_text_view_get_buffer (GTK_TEXT_VIEW (ghm_log_view)),log_message,strlen(log_message));
gtk_text_view_scroll_mark_onscreen (GTK_TEXT_VIEW (ghm_log_view), gtk_text_buffer_get_insert(gtk_text_view_get_buffer (GTK_TEXT_VIEW (ghm_log_view))));

if (index_files(dest_dir) == 0)
{
	strcpy(log_message, _("OK\n"));
	gtk_text_buffer_insert_at_cursor(gtk_text_view_get_buffer (GTK_TEXT_VIEW (ghm_log_view)),log_message,strlen(log_message));
	gtk_text_view_scroll_mark_onscreen (GTK_TEXT_VIEW (ghm_log_view), gtk_text_buffer_get_insert(gtk_text_view_get_buffer (GTK_TEXT_VIEW (ghm_log_view))));
}

else
{
	strcpy(log_message, _("FAILED\nProcess stopped."));
	gtk_text_buffer_insert_at_cursor(gtk_text_view_get_buffer (GTK_TEXT_VIEW (ghm_log_view)),log_message,strlen(log_message));
	gtk_text_view_scroll_mark_onscreen (GTK_TEXT_VIEW (ghm_log_view), gtk_text_buffer_get_insert(gtk_text_view_get_buffer (GTK_TEXT_VIEW (ghm_log_view))));
	gtk_statusbar_push(GTK_STATUSBAR (statusbar1), context_id, _("Process failed! See log for more information."));
	return 1;
}


// Opens file by file and changes it permissions and contents

strcpy(log_message, _("Changing files...\n"));
gtk_text_buffer_insert_at_cursor(gtk_text_view_get_buffer (GTK_TEXT_VIEW (ghm_log_view)),log_message,strlen(log_message));
gtk_text_view_scroll_mark_onscreen (GTK_TEXT_VIEW (ghm_log_view), gtk_text_buffer_get_insert(gtk_text_view_get_buffer (GTK_TEXT_VIEW (ghm_log_view))));

// Open the index file and read line by line
strcpy(fileline,dest_dir);
strcat(fileline,"/ghm_dirlist.txt");
	
if ((current_file = fopen(fileline, "r")) == NULL)
	{
		strcpy(log_message, _("FAILED\nProcess stopped."));
		gtk_text_buffer_insert_at_cursor(gtk_text_view_get_buffer (GTK_TEXT_VIEW (ghm_log_view)),log_message,strlen(log_message));
		gtk_text_view_scroll_mark_onscreen (GTK_TEXT_VIEW (ghm_log_view), gtk_text_buffer_get_insert(gtk_text_view_get_buffer (GTK_TEXT_VIEW (ghm_log_view))));
		gtk_statusbar_push(GTK_STATUSBAR (statusbar1), context_id, _("Process failed! See log for more information."));
		return 1;
	}

strcpy(current_dir, dest_dir);

while (fgets(fileline, sizeof(fileline), current_file) != NULL) 
	{
	// Clears the newline character
	strcpy(fileline, replacestr(fileline,"\n",""));
	
		
	// Check if it is a dir
	if (strstr(fileline,":") != NULL)
		{
		strcpy(current_dir,replacestr(fileline,":",""));		
		}

	// Ignores directories, sym links, empty lines, and "ghm_dirlist.txt" files
	// and makes the appropriate changes to the other files		
	if (strstr(fileline,"/") == NULL && strstr(fileline,"@") == NULL && strstr(fileline,"ghm_dir_list.txt") == NULL && strlen(fileline) > 0)
	{
		// File location
		strcpy(new_file_loc, current_dir);
		strcat(new_file_loc, "/");
		strcat(new_file_loc, fileline);
		
		//Changes the file name
		if(string_check != 0 && strstr(fileline,source_user) != NULL)
		{
			if (search_replace_filename(fileline, current_dir, source_user, dest_user) != 0)
			{
				strcpy(log_message, new_file_loc);
				strcat(log_message, " RENAME FAILED\n");
				gtk_text_buffer_insert_at_cursor(gtk_text_view_get_buffer (GTK_TEXT_VIEW (ghm_log_view)),log_message,strlen(log_message));
				gtk_text_view_scroll_mark_onscreen (GTK_TEXT_VIEW (ghm_log_view), gtk_text_buffer_get_insert(gtk_text_view_get_buffer (GTK_TEXT_VIEW (ghm_log_view))));
			}
			else
			{
				strcpy(new_file_loc, current_dir);
				strcat(new_file_loc, "/");
				strcat(new_file_loc,replacestr(fileline,source_user,dest_user));		
			}
		}
		
		// Executes the SMART check on the file
		smart_check_result = smart_file_select(new_file_loc);
		
		//Changes the file contents (directory and user references)
		if(string_check != 0 && (smart_check_result == 0 || smart_check == 0))
		{
			if (search_replace_onfile(new_file_loc, source_dir, dest_dir) != 0 || search_replace_onfile(new_file_loc, source_user, dest_user) != 0)
			{
				strcpy(log_message, new_file_loc);
				strcat(log_message, " REPLACE REFERENCES FAILED\n");
				gtk_text_buffer_insert_at_cursor(gtk_text_view_get_buffer (GTK_TEXT_VIEW (ghm_log_view)),log_message,strlen(log_message));
				gtk_text_view_scroll_mark_onscreen (GTK_TEXT_VIEW (ghm_log_view), gtk_text_buffer_get_insert(gtk_text_view_get_buffer (GTK_TEXT_VIEW (ghm_log_view))));
			}
			else
			{
				strcpy(log_message, new_file_loc);
				strcat(log_message, " OK\n");
				gtk_text_buffer_insert_at_cursor(gtk_text_view_get_buffer (GTK_TEXT_VIEW (ghm_log_view)),log_message,strlen(log_message));
				gtk_text_view_scroll_mark_onscreen (GTK_TEXT_VIEW (ghm_log_view), gtk_text_buffer_get_insert(gtk_text_view_get_buffer (GTK_TEXT_VIEW (ghm_log_view))));
			}
		}
		
		// List files ignored by SMART
		if(string_check != 0 && smart_check_result != 0 && smart_check != 0)
		{
			strcpy(log_message, new_file_loc);
			strcat(log_message, " IGNORED BY SMART\n");
			gtk_text_buffer_insert_at_cursor(gtk_text_view_get_buffer (GTK_TEXT_VIEW (ghm_log_view)),log_message,strlen(log_message));
			gtk_text_view_scroll_mark_onscreen (GTK_TEXT_VIEW (ghm_log_view), gtk_text_buffer_get_insert(gtk_text_view_get_buffer (GTK_TEXT_VIEW (ghm_log_view))));
		}
		
	// Refresh the Screen (to show the messages in real time)
	while (gtk_events_pending ()) gtk_main_iteration ();
		
	} // Close of the files action
		
	} // Close of the index loop
		
fclose(current_file);

strcpy(log_message, _("Changing Files... OK\n"));
gtk_text_buffer_insert_at_cursor(gtk_text_view_get_buffer (GTK_TEXT_VIEW (ghm_log_view)),log_message,strlen(log_message));
gtk_text_view_scroll_mark_onscreen (GTK_TEXT_VIEW (ghm_log_view), gtk_text_buffer_get_insert(gtk_text_view_get_buffer (GTK_TEXT_VIEW (ghm_log_view))));
	
// Changes the OWNERS of the destination DIR
if (chown_check != 0)
{
strcpy(log_message, _("Changing Owner..."));
gtk_text_buffer_insert_at_cursor(gtk_text_view_get_buffer (GTK_TEXT_VIEW (ghm_log_view)),log_message,strlen(log_message));
gtk_text_view_scroll_mark_onscreen (GTK_TEXT_VIEW (ghm_log_view), gtk_text_buffer_get_insert(gtk_text_view_get_buffer (GTK_TEXT_VIEW (ghm_log_view))));

	if(dir_chown(dest_dir, source_user, dest_user, source_group, dest_group) != 0)
	{
		strcpy(log_message, _("FAILED\n"));
		gtk_text_buffer_insert_at_cursor(gtk_text_view_get_buffer (GTK_TEXT_VIEW (ghm_log_view)),log_message,strlen(log_message));
		gtk_text_view_scroll_mark_onscreen (GTK_TEXT_VIEW (ghm_log_view), gtk_text_buffer_get_insert(gtk_text_view_get_buffer (GTK_TEXT_VIEW (ghm_log_view))));
	}
	
	else
	{
		strcpy(log_message, _("OK\n"));
		gtk_text_buffer_insert_at_cursor(gtk_text_view_get_buffer (GTK_TEXT_VIEW (ghm_log_view)),log_message,strlen(log_message));
		gtk_text_view_scroll_mark_onscreen (GTK_TEXT_VIEW (ghm_log_view), gtk_text_buffer_get_insert(gtk_text_view_get_buffer (GTK_TEXT_VIEW (ghm_log_view))));
	}
}

// Delete the file list index (it is not necessary to display any message).
strcpy(commando,"rm ");
strcat(commando, dest_dir);
strcat(commando, "/ghm_dirlist.txt");
strcpy(log_message, _("Removing file index..."));
gtk_text_buffer_insert_at_cursor(gtk_text_view_get_buffer (GTK_TEXT_VIEW (ghm_log_view)),log_message,strlen(log_message));
	gtk_text_view_scroll_mark_onscreen (GTK_TEXT_VIEW (ghm_log_view), gtk_text_buffer_get_insert(gtk_text_view_get_buffer (GTK_TEXT_VIEW (ghm_log_view))));
if (system(commando) == 0)
{
	strcpy(log_message, _("OK\n"));
	gtk_text_buffer_insert_at_cursor(gtk_text_view_get_buffer (GTK_TEXT_VIEW (ghm_log_view)),log_message,strlen(log_message));
	gtk_text_view_scroll_mark_onscreen (GTK_TEXT_VIEW (ghm_log_view), gtk_text_buffer_get_insert(gtk_text_view_get_buffer (GTK_TEXT_VIEW (ghm_log_view))));
}

else
{
	strcpy(log_message, _("FAILED\n"));
	gtk_text_buffer_insert_at_cursor(gtk_text_view_get_buffer (GTK_TEXT_VIEW (ghm_log_view)),log_message,strlen(log_message));
	gtk_text_view_scroll_mark_onscreen (GTK_TEXT_VIEW (ghm_log_view), gtk_text_buffer_get_insert(gtk_text_view_get_buffer (GTK_TEXT_VIEW (ghm_log_view))));
}

// Finished message
strcpy(log_message, _("Process finished. See the log above for non critical errors.\n\n"));
gtk_text_buffer_insert_at_cursor(gtk_text_view_get_buffer (GTK_TEXT_VIEW (ghm_log_view)),log_message,strlen(log_message));
gtk_text_view_scroll_mark_onscreen (GTK_TEXT_VIEW (ghm_log_view), gtk_text_buffer_get_insert(gtk_text_view_get_buffer (GTK_TEXT_VIEW (ghm_log_view))));

gtk_statusbar_push(GTK_STATUSBAR (statusbar1), context_id, _("Finished!"));

return 0;
} // End of button pressed

void
on_window1_destroy                     (GtkObject       *object,
                                        gpointer         user_data)
{
exit_program_routines();
}

void
on_ghm_quit_btn_clicked                (GtkButton       *button,
                                        gpointer         user_data)
{
exit_program_routines();
}

void
on_ghm_help_btn_clicked                (GtkButton       *button,
                                        gpointer         user_data)
{

}

void
on_ghm_dest_user_changed               (GtkEditable     *editable,
                                        gpointer         user_data)
{
GtkWidget *ghm_dest_user = lookup_widget(GTK_WIDGET(editable), "ghm_dest_user");
GtkWidget *ghm_dest_dir = lookup_widget(GTK_WIDGET(editable), "ghm_dest_dir");
	
char dest_user[512];
char dest_dir[512];

strcpy(dest_dir, "/home/");
strcpy(dest_user, gtk_entry_get_text (GTK_ENTRY (ghm_dest_user)));
strcat(dest_dir, dest_user);
gtk_entry_set_text (GTK_ENTRY (ghm_dest_dir), dest_dir);

}


void
on_ghm_source_user_changed             (GtkEditable     *editable,
                                        gpointer         user_data)
{
GtkWidget *ghm_source_user = lookup_widget(GTK_WIDGET(editable), "ghm_source_user");
GtkWidget *ghm_source_dir = lookup_widget(GTK_WIDGET(editable), "ghm_source_dir");
	
char source_user[512];
char source_dir[512];

strcpy(source_dir, "/home/");
strcpy(source_user, gtk_entry_get_text (GTK_ENTRY (ghm_source_user)));
strcat(source_dir, source_user);
gtk_entry_set_text (GTK_ENTRY (ghm_source_dir), source_dir);
	
}

void
on_ghm_about_btn_clicked               (GtkButton       *button,
                                        gpointer         user_data)
{
GtkWidget *window2;
window2 = create_window2 ();
gtk_widget_show (window2);
}

void
on_ghm_about_ok_clicked                (GtkButton       *button,
                                        gpointer         user_data)
{
GtkWidget *window2 = lookup_widget(GTK_WIDGET(button), "window2");
gtk_widget_destroy(window2);
}

void
on_window1_show                        (GtkWidget       *widget,
                                        gpointer         user_data)
{
// Log View
GtkWidget *statusbar1 = lookup_widget(GTK_WIDGET(widget), "statusbar1");

// Set a status bar message
int context_id = gtk_statusbar_get_context_id(GTK_STATUSBAR (statusbar1), _("G Home Mover Status Bar"));
	
gtk_statusbar_push(GTK_STATUSBAR (statusbar1), context_id, _("WARNING! All files in the DESTINATION directory will be OVERWRITTEN."));

	
}
